@@ -6,6 +6,7 @@ from unittest.mock import MagicMock
 import httpx
 import pytest
 import respx
+from _pytest.monkeypatch import MonkeyPatch
 from pydantic import HttpUrl
 
 from github_issues_import.client import ApiClient, HttpClient
@@ -46,7 +47,7 @@ def test_headers_override(respx_mock: respx.mock):
     assert "Authorization" not in respx_mock.calls.last.request.headers
 
 
-def test_event_hooks_override(monkeypatch, respx_mock: respx.mock):
+def test_event_hooks_override(monkeypatch: MonkeyPatch, respx_mock: respx.mock):
     respx_mock.get().mock(return_value=RESPONSE_STATUS_MULTIPLE_ISSUES)
 
     mock_log_request, mock_log_response = MagicMock(), MagicMock()
@@ -60,7 +61,7 @@ def test_event_hooks_override(monkeypatch, respx_mock: respx.mock):
     mock_log_response.assert_not_called()
 
 
-def test_default_event_hooks(monkeypatch, respx_mock: respx.mock):
+def test_event_hooks_default(monkeypatch: MonkeyPatch, respx_mock: respx.mock):
     respx_mock.post("https://api.github.com/repos/foo/bar/import/issues").mock(
         return_value=httpx.Response(httpx.codes.BAD_GATEWAY)
     )
@@ -71,15 +72,16 @@ def test_default_event_hooks(monkeypatch, respx_mock: respx.mock):
 
     api_client = ApiClient(http_client=HttpClient(token=GITHUB_TOKEN))
 
-    with pytest.raises(httpx.HTTPStatusError):
+    with pytest.raises(httpx.HTTPStatusError) as excinfo:
         api_client.import_issue(
             "foo",
             "bar",
             IssueImportRequest.model_validate_json(get_fixture("request-issue-and-comment-fields.json")),
         )
+    assert "502 Bad Gateway" in str(excinfo.value)
 
-    mock_log_request.assert_called()
-    mock_log_response.assert_called()
+    mock_log_request.assert_called_once()
+    mock_log_response.assert_called_once()
 
 
 def test_import_issue(api_client: ApiClient, respx_mock: respx.mock):
